@@ -62,7 +62,8 @@ class TestMp(unittest.TestCase):
         self.loop.close()
         if len(multiprocessing.active_children()) > 0:
             # STM-8031: Wait for all threads to stop
-            time.sleep(0.1)
+            # Increased sleep to avoid Github Actions flakiness
+            time.sleep(0.3)
 
     def _await(self, co):
         return self.loop.run_until_complete(co)
@@ -124,9 +125,10 @@ class TestMp(unittest.TestCase):
         self.assertEqual(self.ctx.num_instances, 2)
 
     def test_mp_config_02(self):
-        """Processes are limited to the available number of CPU cores."""
+        """Processes are limited to the available number of CPU cores.
+           We need to set fake=False to enable this logic in context.py for testing"""
         cores = len(os.sched_getaffinity(os.getpid()))
-        self.ctx = Context('test', {}, None, {}, netpoller_cfg={'processes': cores + 1})
+        self.ctx = Context('test', {}, None, {}, netpoller_cfg={'processes': cores + 1}, fake=False)
         self.assertEqual(self.ctx.num_instances, cores)
 
     def test_mp_01(self):
